
//
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
// 
//   http://www.apache.org/licenses/LICENSE-2.0
// 
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.
//

// This source file was created by a code generator.
// Please do not edit.

#include "QmfPackage.h"
#include <qmf/Schema.h>
#include <qmf/SchemaProperty.h>
#include <qmf/SchemaMethod.h>
#include <string>

using namespace std;
using namespace qmf::org::matahariproject;

void PackageDefinition::configure(::qmf::AgentSession& session)
{
    string package("org.matahariproject");

    //
    // Data: Services
    //
    data_Services = qmf::Schema(SCHEMA_TYPE_DATA, package, "Services");
    {
        qmf::SchemaProperty prop("uuid", qmf::SCHEMA_DATA_STRING);
        prop.setAccess(qmf::ACCESS_READ_ONLY);
        prop.setDesc("Host UUID");
        data_Services.addProperty(prop);
    }

    {
        qmf::SchemaProperty prop("hostname", qmf::SCHEMA_DATA_STRING);
        prop.setAccess(qmf::ACCESS_READ_ONLY);
        prop.setIndex(true);
        prop.setDesc("Hostname");
        data_Services.addProperty(prop);
    }

    {
        qmf::SchemaProperty prop("qmf-gen-no-crash", qmf::SCHEMA_DATA_INT);
        prop.setSubtype("abstime");
        prop.setDesc("Dummy stat to stop qmf-gen from crashing.");
        data_Services.addProperty(prop);
    }

    {
        qmf::SchemaMethod method("list");
        method.setDesc("List known system services");
        {
            qmf::SchemaProperty arg("agents", qmf::SCHEMA_DATA_LIST);
            arg.setDirection(qmf::DIR_OUT);
            method.addArgument(arg);
        }

        data_Services.addMethod(method);
    }

    {
        qmf::SchemaMethod method("enable");
        method.setDesc("Configure a system service to start at boot");
        {
            qmf::SchemaProperty arg("name", qmf::SCHEMA_DATA_STRING);
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("rc", qmf::SCHEMA_DATA_INT);
            arg.setDirection(qmf::DIR_OUT);
            method.addArgument(arg);
        }

        data_Services.addMethod(method);
    }

    {
        qmf::SchemaMethod method("disable");
        method.setDesc("Configure a system service _not_ to start at boot");
        {
            qmf::SchemaProperty arg("name", qmf::SCHEMA_DATA_STRING);
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("rc", qmf::SCHEMA_DATA_INT);
            arg.setDirection(qmf::DIR_OUT);
            method.addArgument(arg);
        }

        data_Services.addMethod(method);
    }

    {
        qmf::SchemaMethod method("start");
        method.setDesc("Start a system service");
        {
            qmf::SchemaProperty arg("name", qmf::SCHEMA_DATA_STRING);
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("timeout", qmf::SCHEMA_DATA_INT);
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("rc", qmf::SCHEMA_DATA_INT);
            arg.setDirection(qmf::DIR_OUT);
            method.addArgument(arg);
        }

        data_Services.addMethod(method);
    }

    {
        qmf::SchemaMethod method("stop");
        method.setDesc("Stop a system service");
        {
            qmf::SchemaProperty arg("name", qmf::SCHEMA_DATA_STRING);
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("timeout", qmf::SCHEMA_DATA_INT);
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("rc", qmf::SCHEMA_DATA_INT);
            arg.setDirection(qmf::DIR_OUT);
            method.addArgument(arg);
        }

        data_Services.addMethod(method);
    }

    {
        qmf::SchemaMethod method("status");
        method.setDesc("Check the health of a system service");
        {
            qmf::SchemaProperty arg("name", qmf::SCHEMA_DATA_STRING);
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("timeout", qmf::SCHEMA_DATA_INT);
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("rc", qmf::SCHEMA_DATA_INT);
            arg.setDirection(qmf::DIR_OUT);
            method.addArgument(arg);
        }

        data_Services.addMethod(method);
    }

    {
        qmf::SchemaMethod method("describe");
        method.setDesc("Obtain XML description of a system service");
        {
            qmf::SchemaProperty arg("name", qmf::SCHEMA_DATA_STRING);
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("xml", qmf::SCHEMA_DATA_STRING);
            arg.setDirection(qmf::DIR_OUT);
            method.addArgument(arg);
        }

        data_Services.addMethod(method);
    }

    session.registerSchema(data_Services);

    //
    // Data: Resources
    //
    data_Resources = qmf::Schema(SCHEMA_TYPE_DATA, package, "Resources");
    {
        qmf::SchemaProperty prop("uuid", qmf::SCHEMA_DATA_STRING);
        prop.setAccess(qmf::ACCESS_READ_ONLY);
        prop.setDesc("Host UUID");
        data_Resources.addProperty(prop);
    }

    {
        qmf::SchemaProperty prop("hostname", qmf::SCHEMA_DATA_STRING);
        prop.setAccess(qmf::ACCESS_READ_ONLY);
        prop.setIndex(true);
        prop.setDesc("Hostname");
        data_Resources.addProperty(prop);
    }

    {
        qmf::SchemaMethod method("list_standards");
        method.setDesc("List known resource standards (OCF, LSB, systemd, etc)");
        {
            qmf::SchemaProperty arg("standards", qmf::SCHEMA_DATA_LIST);
            arg.setDirection(qmf::DIR_OUT);
            method.addArgument(arg);
        }

        data_Resources.addMethod(method);
    }

    {
        qmf::SchemaMethod method("list_providers");
        method.setDesc("List known providers (if supported) for a given standard");
        {
            qmf::SchemaProperty arg("standard", qmf::SCHEMA_DATA_STRING);
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("providers", qmf::SCHEMA_DATA_LIST);
            arg.setDirection(qmf::DIR_OUT);
            method.addArgument(arg);
        }

        data_Resources.addMethod(method);
    }

    {
        qmf::SchemaMethod method("list");
        method.setDesc("List known resource types for a given standard and provider");
        {
            qmf::SchemaProperty arg("standard", qmf::SCHEMA_DATA_STRING);
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("provider", qmf::SCHEMA_DATA_STRING);
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("agents", qmf::SCHEMA_DATA_LIST);
            arg.setDirection(qmf::DIR_OUT);
            method.addArgument(arg);
        }

        data_Resources.addMethod(method);
    }

    {
        qmf::SchemaMethod method("describe");
        method.setDesc("Obtain XML description of a resource");
        {
            qmf::SchemaProperty arg("standard", qmf::SCHEMA_DATA_STRING);
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("provider", qmf::SCHEMA_DATA_STRING);
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("agent", qmf::SCHEMA_DATA_STRING);
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("xml", qmf::SCHEMA_DATA_STRING);
            arg.setDirection(qmf::DIR_OUT);
            method.addArgument(arg);
        }

        data_Resources.addMethod(method);
    }

    {
        qmf::SchemaMethod method("invoke");
        method.setDesc("Perform a custom action on a resource");
        {
            qmf::SchemaProperty arg("name", qmf::SCHEMA_DATA_STRING);
            arg.setDesc("Identification of the action");
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("standard", qmf::SCHEMA_DATA_STRING);
            arg.setDesc("Resource standard to be used, see <xref linkend='Resources_list_standards' />");
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("provider", qmf::SCHEMA_DATA_STRING);
            arg.setDesc("Provider of ocf standard, see <xref linkend='Resources_list_providers' />");
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("agent", qmf::SCHEMA_DATA_STRING);
            arg.setDesc("Name of the resource affected by action");
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("action", qmf::SCHEMA_DATA_STRING);
            arg.setDesc("Action that will be executed on resource");
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("interval", qmf::SCHEMA_DATA_INT);
            arg.setDesc("Event resource_op will be risen each interval miliseconds (not supported by dbus agent)");
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("parameters", qmf::SCHEMA_DATA_MAP);
            arg.setDesc("Additional parameters for the action (enviromental variables for OCF)");
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("timeout", qmf::SCHEMA_DATA_INT);
            arg.setDesc("Timeout for the action in miliseconds");
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("expected-rc", qmf::SCHEMA_DATA_INT);
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("rc", qmf::SCHEMA_DATA_INT);
            arg.setDesc("Return code of the action");
            arg.setDirection(qmf::DIR_OUT);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("sequence", qmf::SCHEMA_DATA_INT);
            arg.setDirection(qmf::DIR_OUT);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("userdata", qmf::SCHEMA_DATA_STRING);
            arg.setDirection(qmf::DIR_IN_OUT);
            method.addArgument(arg);
        }

        data_Resources.addMethod(method);
    }

    {
        qmf::SchemaMethod method("cancel");
        method.setDesc("Cancel a pending or running action on a resource. name, action and interval must be the same as for invoke method");
        {
            qmf::SchemaProperty arg("name", qmf::SCHEMA_DATA_STRING);
            arg.setDesc("Identification of the action");
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("action", qmf::SCHEMA_DATA_STRING);
            arg.setDesc("Action that is running or pending");
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("interval", qmf::SCHEMA_DATA_INT);
            arg.setDesc("Interval in miliseconds");
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("timeout", qmf::SCHEMA_DATA_INT);
            arg.setDesc("Timeout for cancelling in miliseconds");
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        data_Resources.addMethod(method);
    }

    {
        qmf::SchemaMethod method("fail");
        method.setDesc("Indicate a resource has failed");
        {
            qmf::SchemaProperty arg("name", qmf::SCHEMA_DATA_STRING);
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("rc", qmf::SCHEMA_DATA_INT);
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        data_Resources.addMethod(method);
    }

    session.registerSchema(data_Resources);

    //
    // Event: resource_op
    //
    event_resource_op = qmf::Schema(SCHEMA_TYPE_EVENT, package, "resource_op");
    event_resource_op.setDefaultSeverity(qmf::SEV_INFORM);
    {
        qmf::SchemaProperty prop("timestamp", qmf::SCHEMA_DATA_INT);
        prop.setSubtype("abstime");
        event_resource_op.addProperty(prop);
    }

    {
        qmf::SchemaProperty prop("sequence", qmf::SCHEMA_DATA_INT);
        event_resource_op.addProperty(prop);
    }

    {
        qmf::SchemaProperty prop("name", qmf::SCHEMA_DATA_STRING);
        event_resource_op.addProperty(prop);
    }

    {
        qmf::SchemaProperty prop("standard", qmf::SCHEMA_DATA_STRING);
        event_resource_op.addProperty(prop);
    }

    {
        qmf::SchemaProperty prop("provider", qmf::SCHEMA_DATA_STRING);
        event_resource_op.addProperty(prop);
    }

    {
        qmf::SchemaProperty prop("agent", qmf::SCHEMA_DATA_STRING);
        event_resource_op.addProperty(prop);
    }

    {
        qmf::SchemaProperty prop("action", qmf::SCHEMA_DATA_STRING);
        event_resource_op.addProperty(prop);
    }

    {
        qmf::SchemaProperty prop("interval", qmf::SCHEMA_DATA_INT);
        event_resource_op.addProperty(prop);
    }

    {
        qmf::SchemaProperty prop("rc", qmf::SCHEMA_DATA_INT);
        event_resource_op.addProperty(prop);
    }

    {
        qmf::SchemaProperty prop("expected-rc", qmf::SCHEMA_DATA_INT);
        event_resource_op.addProperty(prop);
    }

    {
        qmf::SchemaProperty prop("userdata", qmf::SCHEMA_DATA_STRING);
        event_resource_op.addProperty(prop);
    }

    session.registerSchema(event_resource_op);

}

